@@ -126,6 +126,8 @@ PyAPI_FUNC(int) PyDateTime_DATE_GET_MICROSECOND(void *arg0);
 PyAPI_FUNC(int) PyDateTime_DATE_GET_MINUTE(void *arg0);
 #define PyDateTime_DATE_GET_SECOND PyPyDateTime_DATE_GET_SECOND
 PyAPI_FUNC(int) PyDateTime_DATE_GET_SECOND(void *arg0);
+#define PyDateTime_DATE_GET_TZINFO PyPyDateTime_DATE_GET_TZINFO
+PyAPI_FUNC(struct _object *) PyDateTime_DATE_GET_TZINFO(void *arg0);
 #define PyDateTime_DELTA_GET_DAYS PyPyDateTime_DELTA_GET_DAYS
 PyAPI_FUNC(int) PyDateTime_DELTA_GET_DAYS(void *arg0);
 #define PyDateTime_DELTA_GET_MICROSECONDS PyPyDateTime_DELTA_GET_MICROSECONDS
@@ -152,6 +154,8 @@ PyAPI_FUNC(int) PyDateTime_TIME_GET_MICROSECOND(void *arg0);
 PyAPI_FUNC(int) PyDateTime_TIME_GET_MINUTE(void *arg0);
 #define PyDateTime_TIME_GET_SECOND PyPyDateTime_TIME_GET_SECOND
 PyAPI_FUNC(int) PyDateTime_TIME_GET_SECOND(void *arg0);
+#define PyDateTime_TIME_GET_TZINFO PyPyDateTime_TIME_GET_TZINFO
+PyAPI_FUNC(struct _object *) PyDateTime_TIME_GET_TZINFO(void *arg0);
 #define PyDate_Check PyPyDate_Check
 PyAPI_FUNC(int) PyDate_Check(struct _object *arg0);
 #define PyDate_CheckExact PyPyDate_CheckExact
@@ -252,8 +256,6 @@ PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilename(struct _object *arg0
 PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilenameObject(struct _object *arg0, struct _object *arg1);
 #define PyErr_SetFromErrnoWithFilenameObjects PyPyErr_SetFromErrnoWithFilenameObjects
 PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilenameObjects(struct _object *arg0, struct _object *arg1, struct _object *arg2);
-#define PyErr_SetInterrupt PyPyErr_SetInterrupt
-PyAPI_FUNC(void) PyErr_SetInterrupt(void);
 #define PyErr_SetNone PyPyErr_SetNone
 PyAPI_FUNC(void) PyErr_SetNone(struct _object *arg0);
 #define PyErr_SetObject PyPyErr_SetObject
@@ -322,6 +324,10 @@ PyAPI_FUNC(int) PyFile_WriteString(const char *arg0, struct _object *arg1);
 PyAPI_FUNC(double) PyFloat_AS_DOUBLE(void *arg0);
 #define PyFloat_AsDouble PyPyFloat_AsDouble
 PyAPI_FUNC(double) PyFloat_AsDouble(struct _object *arg0);
+#define PyFloat_Check PyPyFloat_Check
+PyAPI_FUNC(int) PyFloat_Check(void * arg0);
+#define PyFloat_CheckExact PyPyFloat_CheckExact
+PyAPI_FUNC(int) PyFloat_CheckExact(void * arg0);
 #define PyFloat_FromDouble PyPyFloat_FromDouble
 PyAPI_FUNC(struct _object *) PyFloat_FromDouble(double arg0);
 #define PyFloat_FromString PyPyFloat_FromString
@@ -340,6 +346,12 @@ PyAPI_FUNC(int) PyFunction_Check(void * arg0);
 PyAPI_FUNC(int) PyFunction_CheckExact(void * arg0);
 #define PyFunction_GetCode PyPyFunction_GetCode
 PyAPI_FUNC(struct _object *) PyFunction_GetCode(struct _object *arg0);
+#define PyGC_Disable PyPyGC_Disable
+PyAPI_FUNC(int) PyGC_Disable(void);
+#define PyGC_Enable PyPyGC_Enable
+PyAPI_FUNC(int) PyGC_Enable(void);
+#define PyGC_IsEnabled PyPyGC_IsEnabled
+PyAPI_FUNC(int) PyGC_IsEnabled(void);
 #define PyGILState_Check PyPyGILState_Check
 PyAPI_FUNC(int) PyGILState_Check(void);
 #define PyGILState_Ensure PyPyGILState_Ensure
@@ -370,8 +382,6 @@ PyAPI_FUNC(PyObject *) PyImport_ImportModuleLevelObject(PyObject * arg0, PyObjec
 PyAPI_FUNC(struct _object *) PyImport_ImportModuleNoBlock(const char *arg0);
 #define PyImport_ReloadModule PyPyImport_ReloadModule
 PyAPI_FUNC(struct _object *) PyImport_ReloadModule(struct _object *arg0);
-#define PyIndex_Check PyPyIndex_Check
-PyAPI_FUNC(int) PyIndex_Check(struct _object *arg0);
 #define PyInstanceMethod_Check PyPyInstanceMethod_Check
 PyAPI_FUNC(int) PyInstanceMethod_Check(struct _object *arg0);
 #define PyInstanceMethod_Function PyPyInstanceMethod_Function
@@ -390,6 +400,8 @@ PyAPI_FUNC(PyInterpreterState *) PyInterpreterState_Next(PyInterpreterState *arg
 PyAPI_FUNC(int) PyIter_Check(struct _object *arg0);
 #define PyIter_Next PyPyIter_Next
 PyAPI_FUNC(struct _object *) PyIter_Next(struct _object *arg0);
+#define PyIter_Send PyPyIter_Send
+PyAPI_FUNC(int) PyIter_Send(struct _object *arg0, struct _object *arg1, struct _object **arg2);
 #define PyList_Append PyPyList_Append
 PyAPI_FUNC(int) PyList_Append(struct _object *arg0, struct _object *arg1);
 #define PyList_AsTuple PyPyList_AsTuple
@@ -536,8 +548,6 @@ PyAPI_FUNC(struct _object *) PyNumber_Add(struct _object *arg0, struct _object *
 PyAPI_FUNC(struct _object *) PyNumber_And(struct _object *arg0, struct _object *arg1);
 #define PyNumber_AsSsize_t PyPyNumber_AsSsize_t
 PyAPI_FUNC(Signed) PyNumber_AsSsize_t(struct _object *arg0, struct _object *arg1);
-#define PyNumber_Check PyPyNumber_Check
-PyAPI_FUNC(int) PyNumber_Check(struct _object *arg0);
 #define PyNumber_Divide PyPyNumber_Divide
 PyAPI_FUNC(struct _object *) PyNumber_Divide(struct _object *arg0, struct _object *arg1);
 #define PyNumber_Divmod PyPyNumber_Divmod
@@ -650,6 +660,10 @@ PyAPI_FUNC(int) PyObject_DelItem(struct _object *arg0, struct _object *arg1);
 PyAPI_FUNC(struct _object *) PyObject_Dir(struct _object *arg0);
 #define PyObject_Format PyPyObject_Format
 PyAPI_FUNC(struct _object *) PyObject_Format(struct _object *arg0, struct _object *arg1);
+#define PyObject_GC_IsFinalized PyPyObject_GC_IsFinalized
+PyAPI_FUNC(int) PyObject_GC_IsFinalized(struct _object *arg0);
+#define PyObject_GC_IsTracked PyPyObject_GC_IsTracked
+PyAPI_FUNC(int) PyObject_GC_IsTracked(struct _object *arg0);
 #define PyObject_GenericGetAttr PyPyObject_GenericGetAttr
 PyAPI_FUNC(struct _object *) PyObject_GenericGetAttr(struct _object *arg0, struct _object *arg1);
 #define PyObject_GenericGetDict PyPyObject_GenericGetDict
@@ -858,12 +872,8 @@ PyAPI_FUNC(Signed) PyTuple_Size(struct _object *arg0);
 PyAPI_FUNC(PyObject *) PyType_FromModuleAndSpec(PyObject * arg0, PyType_Spec * arg1, PyObject * arg2);
 #define PyType_FromSpecWithBases PyPyType_FromSpecWithBases
 PyAPI_FUNC(PyObject *) PyType_FromSpecWithBases(PyType_Spec * arg0, PyObject * arg1);
-#define PyType_GenericNew PyPyType_GenericNew
-PyAPI_FUNC(struct _object *) PyType_GenericNew(struct _typeobject *arg0, struct _object *arg1, struct _object *arg2);
 #define PyType_GetSlot PyPyType_GetSlot
 PyAPI_FUNC(void *) PyType_GetSlot(struct _typeobject *arg0, int arg1);
-#define PyType_IsSubtype PyPyType_IsSubtype
-PyAPI_FUNC(int) PyType_IsSubtype(struct _typeobject *arg0, struct _typeobject *arg1);
 #define PyType_Modified PyPyType_Modified
 PyAPI_FUNC(void) PyType_Modified(struct _typeobject *arg0);
 #define PyType_Ready PyPyType_Ready
@@ -1128,6 +1138,8 @@ PyAPI_FUNC(int) _PyImport_ReleaseLock(void);
 PyAPI_FUNC(struct _object *) _PyList_Extend(struct _object *arg0, struct _object *arg1);
 #define _PyLong_AsByteArrayO _PyPyLong_AsByteArrayO
 PyAPI_FUNC(int) _PyLong_AsByteArrayO(struct _object *arg0, unsigned char *arg1, Unsigned arg2, int arg3, int arg4);
+#define _PyLong_AsInt _PyPyLong_AsInt
+PyAPI_FUNC(int) _PyLong_AsInt(struct _object *arg0);
 #define _PyLong_FromByteArray _PyPyLong_FromByteArray
 PyAPI_FUNC(struct _object *) _PyLong_FromByteArray(const unsigned char *arg0, Unsigned arg1, int arg2, int arg3);
 #define _PyLong_NumBits _PyPyLong_NumBits
@@ -1169,7 +1181,7 @@ PyAPI_FUNC(int) _PyUnicode_EqualToASCIIString(struct _object *arg0, const char *
 #define _PyUnicode_Ready _PyPyUnicode_Ready
 PyAPI_FUNC(int) _PyUnicode_Ready(PyObject * arg0);
 #define _Py_HashDouble _PyPy_HashDouble
-PyAPI_FUNC(Signed) _Py_HashDouble(double arg0);
+PyAPI_FUNC(Signed) _Py_HashDouble(struct _object *arg0, double arg1);
 #define _Py_HashPointer _PyPy_HashPointer
 PyAPI_FUNC(Signed) _Py_HashPointer(void *arg0);
 #define _Py_IsFinalizing _PyPy_IsFinalizing
@@ -1220,6 +1232,8 @@ PyAPI_DATA(PyObject*) PyExc_ConnectionResetError;
 PyAPI_DATA(PyObject*) PyExc_DeprecationWarning;
 #define PyExc_EOFError PyPyExc_EOFError
 PyAPI_DATA(PyObject*) PyExc_EOFError;
+#define PyExc_EncodingWarning PyPyExc_EncodingWarning
+PyAPI_DATA(PyObject*) PyExc_EncodingWarning;
 #define PyExc_Exception PyPyExc_Exception
 PyAPI_DATA(PyObject*) PyExc_Exception;
 #define PyExc_FileExistsError PyPyExc_FileExistsError
@@ -1318,8 +1332,6 @@ PyAPI_DATA(PyObject*) PyExc_ValueError;
 PyAPI_DATA(PyObject*) PyExc_Warning;
 #define PyExc_ZeroDivisionError PyPyExc_ZeroDivisionError
 PyAPI_DATA(PyObject*) PyExc_ZeroDivisionError;
-#define PyType_Type PyPyType_Type
-PyAPI_DATA(PyTypeObject) PyType_Type;
 #define PyBytes_Type PyPyBytes_Type
 PyAPI_DATA(PyTypeObject) PyBytes_Type;
 #define PyUnicode_Type PyPyUnicode_Type
